@@ -644,17 +644,14 @@ class KiwoomOpenApiPlusTrEventHandler(KiwoomOpenApiPlusEventHandlerForGrpc, Logg
             should_stop = prevnext in ["", "0"]
             repeat_cnt = self.control.GetRepeatCnt(trcode, recordname)
 
-            if len(self._single_names) > 0:
-                values = [
-                    self.control.GetCommData(trcode, recordname, 0, name).strip()
-                    for name in self._single_names
-                ]
-                response.single_data.names.extend(
-                    self._single_names
-                )  # pylint: disable=no-member
-                response.single_data.values.extend(values)  # pylint: disable=no-member
-
             if repeat_cnt > 0:
+                if len(self._multi_names) == 0:
+                    self.logger.warning(
+                        "Repeat count greater than 0, but no multi data names available, fallback to sigle data names"
+                    )
+                    multi_names = self._multi_names
+                    self._multi_names = self._single_names
+                    self._single_name = multi_names
                 if len(self._multi_names) > 0:
                     rows = [
                         [
@@ -669,20 +666,19 @@ class KiwoomOpenApiPlusTrEventHandler(KiwoomOpenApiPlusEventHandlerForGrpc, Logg
                         self._multi_names
                     )  # pylint: disable=no-member
                     for row in rows:
-                        if self._is_stop_condition(row):
-                            should_stop = True
-                            if self._include_equal:
-                                response.multi_data.values.add().values.extend(
-                                    row
-                                )  # pylint: disable=no-member
-                            break
                         response.multi_data.values.add().values.extend(
                             row
                         )  # pylint: disable=no-member
-                else:
-                    self.logger.warning(
-                        "Repeat count greater than 0, but no multi data names available."
-                    )
+
+            if len(self._single_names) > 0:
+                values = [
+                    self.control.GetCommData(trcode, recordname, 0, name).strip()
+                    for name in self._single_names
+                ]
+                response.single_data.names.extend(
+                    self._single_names
+                )  # pylint: disable=no-member
+                response.single_data.values.extend(values)  # pylint: disable=no-member
 
             self.observer.on_next(response)
 
@@ -832,17 +828,14 @@ class KiwoomOpenApiPlusKwTrEventHandler(KiwoomOpenApiPlusEventHandlerForGrpc, Lo
             should_stop = prevnext in ["", "0"]
             repeat_cnt = self.control.GetRepeatCnt(trcode, recordname)
 
-            if len(self._single_names) > 0:
-                values = [
-                    self.control.GetCommData(trcode, recordname, 0, name).strip()
-                    for name in self._single_names
-                ]
-                response.single_data.names.extend(
-                    self._single_names
-                )  # pylint: disable=no-member
-                response.single_data.values.extend(values)  # pylint: disable=no-member
-
             if repeat_cnt > 0:
+                if len(self._multi_names) == 0:
+                    self.logger.warning(
+                        "Repeat count greater than 0, but no multi data names available, fallback to sigle data names"
+                    )
+                    multi_names = self._multi_names
+                    self._multi_names = self._single_names
+                    self._single_name = multi_names
                 if len(self._multi_names) > 0:
                     rows = [
                         [
@@ -857,20 +850,19 @@ class KiwoomOpenApiPlusKwTrEventHandler(KiwoomOpenApiPlusEventHandlerForGrpc, Lo
                         self._multi_names
                     )  # pylint: disable=no-member
                     for row in rows:
-                        if self._is_stop_condition(row):
-                            should_stop = True
-                            if self._include_equal:
-                                response.multi_data.values.add().values.extend(
-                                    row
-                                )  # pylint: disable=no-member
-                            break
                         response.multi_data.values.add().values.extend(
                             row
                         )  # pylint: disable=no-member
-                else:
-                    self.logger.warning(
-                        "Repeat count greater than 0, but no multi data names available."
-                    )
+
+            if len(self._single_names) > 0:
+                values = [
+                    self.control.GetCommData(trcode, recordname, 0, name).strip()
+                    for name in self._single_names
+                ]
+                response.single_data.names.extend(
+                    self._single_names
+                )  # pylint: disable=no-member
+                response.single_data.values.extend(values)  # pylint: disable=no-member
 
             self.observer.on_next(response)
 
@@ -1099,7 +1091,7 @@ class KiwoomOpenApiPlusOrderEventHandler(
         self.add_callback(self._screen_manager.return_screen, self._scrnno)
         self.add_callback(self.control.DisconnectRealData, self._scrnno)
         KiwoomOpenApiPlusError.try_or_raise(
-            self.control.RatedLimitedSendOrder(
+            self.control.RateLimitedSendOrder(
                 self._rqname,
                 self._scrnno,
                 self._accno,
@@ -1400,7 +1392,7 @@ class KiwoomOpenApiPlusConditionEventHandler(
             self._condition_index,
         )
         KiwoomOpenApiPlusError.try_or_raise_boolean(
-            self.control.SendCondition(
+            self.control.RateLimitedSendCondition(
                 self._screen_no,
                 self._condition_name,
                 self._condition_index,
@@ -1458,7 +1450,7 @@ class KiwoomOpenApiPlusConditionEventHandler(
             elif should_continue:
                 try:
                     raise KiwoomOpenApiPlusError("Should not reach here")
-                    self.control.SendCondition(
+                    self.control.RateLimitedSendCondition(
                         self._screen_no,
                         self._condition_name,
                         self._condition_index,
@@ -1537,17 +1529,14 @@ class KiwoomOpenApiPlusConditionEventHandler(
 
             assert trcode.upper() == self._trcode
 
-            if len(self._single_names) > 0:
-                values = [
-                    self.control.GetCommData(trcode, recordname, 0, name).strip()
-                    for name in self._single_names
-                ]
-                response.single_data.names.extend(
-                    self._single_names
-                )  # pylint: disable=no-member
-                response.single_data.values.extend(values)  # pylint: disable=no-member
-
             if repeat_cnt > 0:
+                if len(self._multi_names) == 0:
+                    self.logger.warning(
+                        "Repeat count greater than 0, but no multi data names available, fallback to sigle data names"
+                    )
+                    multi_names = self._multi_names
+                    self._multi_names = self._single_names
+                    self._single_name = multi_names
                 if len(self._multi_names) > 0:
                     rows = [
                         [
@@ -1565,10 +1554,16 @@ class KiwoomOpenApiPlusConditionEventHandler(
                         response.multi_data.values.add().values.extend(
                             row
                         )  # pylint: disable=no-member
-                else:
-                    self.logger.warning(
-                        "Repeat count greater than 0, but no multi data names available."
-                    )
+
+            if len(self._single_names) > 0:
+                values = [
+                    self.control.GetCommData(trcode, recordname, 0, name).strip()
+                    for name in self._single_names
+                ]
+                response.single_data.names.extend(
+                    self._single_names
+                )  # pylint: disable=no-member
+                response.single_data.values.extend(values)  # pylint: disable=no-member
 
             self.observer.on_next(response)  # pylint: disable=no-member
 
